@@ -11,11 +11,8 @@ class ny_eitc(Variable):
     defined_for = StateCode.NY
 
     def formula(tax_unit, period, parameters):
-        in_ny = tax_unit.household("state_code_str", period) == "NY"
         eitc = tax_unit("earned_income_tax_credit", period)
-        rate = parameters(
-            period
-        ).gov.states.ny.tax.income.credits.refundable.eitc
+        rate = parameters(period).gov.states.ny.tax.income.credits.eitc.match
         tentative_nys_eic = eitc * rate
         household_credit = tax_unit("ny_household_credit", period)
-        return in_ny * max_(0, tentative_nys_eic - household_credit)
+        return max_(0, tentative_nys_eic - household_credit)
